@@ -116,7 +116,6 @@ OC.L10N.register(
     "Could not update calendar order." : "لا يمكن تعديل ترتيب التقويم.",
     "Shared calendars" : "تقاويم مشتركة",
     "Deck" : "البطاقات",
-    "Hidden" : "مخفي",
     "Internal link" : "رابط داخلي",
     "A private link that can be used with external clients" : "رابط خاص يمكن استخدامه مع العملاء الخارجيين",
     "Copy internal link" : "إنسخ الرابط الداخلي",
@@ -139,12 +138,10 @@ OC.L10N.register(
     "{teamDisplayName} (Team)" : "{teamDisplayName} (فريق)",
     "An error occurred while unsharing the calendar." : "حدث خطأ أثناء إلغاء مشاركة التقويم",
     "An error occurred, unable to change the permission of the share." : "حدث خطأ، لا يمكن تعديل صلاحيات نشر التقويم.",
-    "can edit" : "يمكن التحرير",
     "Unshare with {displayName}" : "إلغاء المشاركة مع {displayName}",
     "Share with users or groups" : "شارك مع مستخدمين او مجموعات",
     "No users or groups" : "لا يوجد مستخدمين أو مجموعات",
     "Failed to save calendar name and color" : "تعذّر حفظ اسم و لون التقويم",
-    "Calendar name …" : "اسم التقويم ...",
     "Never show me as busy (set this calendar to transparent)" : "لا تُظهرني مطلقًا مشغولاً (اضبط هذا التقويم على شفاف)",
     "Share calendar" : "مُشاركة التقويم",
     "Unshare from me" : "أنت ألغيت المشاركة",
@@ -162,7 +159,7 @@ OC.L10N.register(
     "Invalid location selected" : "الموقع المُختار غير صحيح",
     "Attachments folder successfully saved." : "تمّ بنجاح حفظ مُجلّد المُرفقات",
     "Error on saving attachments folder." : "خطأ في حفظ مُجلّد المُرفقات",
-    "Default attachments location" : "موقع المُرفقات التلقائي",
+    "Attachments folder" : "مجلد المرفقات",
     "{filename} could not be parsed" : "{filename} لم يُمكن تحليله",
     "No valid files found, aborting import" : "لم يٌمكن إيجاد ملفّاتٍ صحيحة. إنهاءُ عملية الاستيراد",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["تم استيراد %n أحداث بنجاح","تم استيراد %n حدث بنجاح","تم استيراد %n أحداث بنجاح","تم استيراد %n أحداث بنجاح","تم استيراد %n أحداث بنجاح","تم استيراد %n أحداث بنجاح"],
@@ -196,13 +193,8 @@ OC.L10N.register(
     "CalDAV link copied to clipboard." : "تم نسخ CalDAV.",
     "CalDAV link could not be copied to clipboard." : "لا يمكن نسخ CalDAV.",
     "General" : "عامٌّ",
-    "Personal availability settings" : "إعدادات التواجد الشخصي",
-    "Copy primary CalDAV address" : "نسخ عنوان CalDAV الرئيسي",
     "Copy iOS/macOS CalDAV address" : "نسخ عنوان CalDAV لأجهزة الماك/الأيفون",
-    "Enable birthday calendar" : "تفعيل تقويم عيد الميلاد",
-    "Show tasks in calendar" : "إظهار المهام في التقويم",
-    "Show weekends" : "إظهار أيام نهاية الاسبوع",
-    "Show week numbers" : "إظهار أرقام الأسابيع",
+    "Appearance" : "المظهر",
     "Editing" : "جارِ التعديل",
     "Default calendar for incoming invitations" : "التقويم التلقائي للدعوات الواردة",
     "Default reminder" : "التذكير الافتراضي",
@@ -348,12 +340,10 @@ OC.L10N.register(
     "Decline" : "رفض",
     "Tentative" : "مؤقت",
     "No attendees yet" : "لا يوجد حضور حتى الآن",
-    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} مدعو, {confirmedCount} مؤكد",
     "Successfully appended link to talk room to location." : "تمّ إلحاق رابط غرفة المحادثة بالموقع بنجاح.",
     "Successfully appended link to talk room to description." : "تمّ إلحاق الرابط بوصف غرفة المحادثة بنجاح.",
     "Error creating Talk room" : "خطأ في انشاء غرفة محادثة",
     "Attendees" : "المشاركون",
-    "_%n more guest_::_%n more guests_" : ["%n ضيفاً آخر","%n ضيفاً آخر","%n ضيفاً آخر","%n ضيوف آخرين","%n ضيفاً آخر","%n ضيفاً آخر"],
     "Remove group" : "حذف مجموعة",
     "Remove attendee" : "إلغاء شخص من قائمة الحضور",
     "Request reply" : "طلب الرّد",
@@ -422,6 +412,7 @@ OC.L10N.register(
     "Yes" : "نعم",
     "No" : "لا",
     "Maybe" : "ربما",
+    "None" : "لا شيء",
     "Create" : "إنشاء",
     "from {formattedDate}" : "من {formattedDate}",
     "to {formattedDate}" : "إلى {formattedDate}",
@@ -563,7 +554,6 @@ OC.L10N.register(
     "When shared show full event" : "عرض الحدث كاملاً عند مشاركته",
     "When shared show only busy" : "عرض \"مشغول\" فقط عند مشاركته",
     "When shared hide this event" : "إخفاء هذا الحدث عند مشاركته",
-    "The visibility of this event in shared calendars." : "ظهور الحدث في التقاويم المشتركة.",
     "Add a location" : "إضافة موقع",
     "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "أضِف وصفاً:\n\n- ماهو موضوع الاجتماع\n- بنود الاجتماع\n- ما يحتاجه المشاركون إلى تحضيره للاجتماع",
     "Status" : "الحالة",
@@ -589,11 +579,24 @@ OC.L10N.register(
     "Error while parsing a PROPFIND error" : "حدث خطأ أثناء تحليل PROFIND",
     "Appointment not found" : "الموعد غير موجود",
     "User not found" : "المستخدم غير موجود",
+    "Hidden" : "مخفي",
+    "can edit" : "يمكن التحرير",
+    "Calendar name …" : "اسم التقويم ...",
+    "Default attachments location" : "موقع المُرفقات التلقائي",
     "Automatic ({detected})" : "تلقائي ({detected})",
     "Shortcut overview" : "نظرة عامة للاختصارات",
+    "Enable birthday calendar" : "تفعيل تقويم عيد الميلاد",
+    "Show tasks in calendar" : "إظهار المهام في التقويم",
     "Enable simplified editor" : "تفعيل المحرر البسيط",
     "Limit the number of events displayed in the monthly view" : "تقييد عدد الأحداث التي تُعرض في العرض الشهري",
+    "Show weekends" : "إظهار أيام نهاية الاسبوع",
+    "Show week numbers" : "إظهار أرقام الأسابيع",
     "Time increments" : "زيادات الوقت",
-    "Show keyboard shortcuts" : "إظهار اختصارات لوحة المفاتيح"
+    "Copy primary CalDAV address" : "نسخ عنوان CalDAV الرئيسي",
+    "Personal availability settings" : "إعدادات التواجد الشخصي",
+    "Show keyboard shortcuts" : "إظهار اختصارات لوحة المفاتيح",
+    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} مدعو, {confirmedCount} مؤكد",
+    "_%n more guest_::_%n more guests_" : ["%n ضيفاً آخر","%n ضيفاً آخر","%n ضيفاً آخر","%n ضيوف آخرين","%n ضيفاً آخر","%n ضيفاً آخر"],
+    "The visibility of this event in shared calendars." : "ظهور الحدث في التقاويم المشتركة."
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
