@@ -14,10 +14,11 @@ OC.L10N.register(
     "Name" : "Ime",
     "Restore" : "Obnovi",
     "Share link" : "Podijelite vezu",
-    "can edit" : "mogu mijenjati",
     "Save" : "Spremi",
     "Cancel" : "Odustani",
     "Actions" : "Radnje",
+    "Keyboard shortcuts" : "Tipkovni prečaci",
+    "Update" : "Ažuriraj",
     "Location" : "Lokacija",
     "Description" : "Opis",
     "to" : "do",
@@ -29,9 +30,13 @@ OC.L10N.register(
     "Friday" : "Petak",
     "Saturday" : "Subota",
     "Sunday" : "Nedjelja",
-    "Update" : "Ažuriraj",
     "Your email address" : "Vaša adresa e-pošte",
     "Email" : "E-pošta",
+    "seconds" : "sekundi",
+    "minutes" : "minuta",
+    "hours" : "sati",
+    "days" : "dana",
+    "weeks" : "sedmica",
     "Busy" : "Zauzet",
     "Unknown" : "Nepoznato",
     "Accept" : "Prihvati",
@@ -39,11 +44,19 @@ OC.L10N.register(
     "Attendees" : "Sudionici",
     "Repeat" : "Ponovi",
     "never" : "nikad",
+    "Yes" : "Da",
+    "No" : "Ne",
+    "None" : "Ništa",
+    "Create" : "Kreiraj",
     "Personal" : "Osobno",
+    "Edit event" : "Izmjeni događaj",
     "Close" : "Zatvori",
+    "Title" : "Naslov",
     "Daily" : "Dnevno",
     "Weekly" : "Sedmično",
+    "second" : "drugi",
     "Other" : "Ostali",
-    "Status" : "Status"
+    "Status" : "Status",
+    "can edit" : "mogu mijenjati"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
