@@ -27,9 +27,7 @@ OC.L10N.register(
     "Restore" : "Restaurar",
     "Delete permanently" : "Borrar permanentemente",
     "Deck" : "Deck",
-    "Hidden" : "Oculto",
     "Share link" : "Compartir liga",
-    "can edit" : "puede editar",
     "Share with users or groups" : "Compartir con otros usuarios o grupos",
     "Save" : "Guardar",
     "Filename" : "Nombre del archivo",
@@ -41,7 +39,6 @@ OC.L10N.register(
     "Actions" : "Acciones",
     "or" : "o",
     "General" : "General",
-    "Show week numbers" : "Mostrar número de semana",
     "Keyboard shortcuts" : "Atajos del teclado",
     "Update" : "Actualizar",
     "Location" : "Ubicación",
@@ -72,6 +69,7 @@ OC.L10N.register(
     "after" : "después",
     "Resources" : "Recursos",
     "available" : "disponible",
+    "None" : "Ninguno",
     "Global" : "Global",
     "Subscribe" : "Suscribir",
     "Personal" : "Personal",
@@ -91,6 +89,9 @@ OC.L10N.register(
     "Status" : "Estatus",
     "Confirmed" : "Confirmado",
     "Categories" : "Categorías",
-    "User not found" : "No se encontró el usuario"
+    "User not found" : "No se encontró el usuario",
+    "Hidden" : "Oculto",
+    "can edit" : "puede editar",
+    "Show week numbers" : "Mostrar número de semana"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
