@@ -19,6 +19,8 @@ OC.L10N.register(
     "Description:" : "Opis:",
     "Date:" : "Datum:",
     "Where:" : "Gdje:",
+    "Location:" : "Lokacija:",
+    "Duration:" : "Trajanje:",
     "A Calendar app for Nextcloud" : "Aplikacija Kalendar za Nextcloud",
     "Previous day" : "Prethodni dan",
     "Previous week" : "Prethodni tjedan",
@@ -70,7 +72,6 @@ OC.L10N.register(
     "Delete permanently" : "Trajno izbrišite",
     "Could not update calendar order." : "Ažuriranje redoslijeda kalendara nije uspjelo.",
     "Deck" : "Deck",
-    "Hidden" : "Skriveno",
     "Internal link" : "Interna poveznica",
     "Copy internal link" : "Kopiraj internu poveznicu",
     "An error occurred, unable to publish calendar." : "Došlo je do pogreške, nije moguće objaviti kalendar.",
@@ -90,24 +91,26 @@ OC.L10N.register(
     "Delete share link" : "Izbriši poveznicu dijeljenja",
     "Deleting share link …" : "Brisanje poveznice dijeljenja...",
     "An error occurred, unable to change the permission of the share." : "Došlo je do pogreške, nije moguće promijeniti dopuštenje dijeljenja.",
-    "can edit" : "uređivanje moguće",
     "Unshare with {displayName}" : "Prekid dijeljenja s {displayName}",
     "Share with users or groups" : "Dijelite s korisnicima ili grupama",
     "No users or groups" : "Nema korisnika ili grupa",
     "Unshare from me" : "Prekid dijeljenja sa mnom",
     "Save" : "Spremi",
+    "View" : "Pregledaj",
     "Import calendars" : "Uvezi kalendare",
     "Please select a calendar to import into …" : "Odaberite kalendar za uvoz...",
     "Filename" : "Naziv datoteke",
     "Calendar to import into" : "Kalendar za uvoz",
     "Cancel" : "Odustani",
     "_Import calendar_::_Import calendars_" : ["Uvezi kalendar","Uvezi kalendare","Uvezi kalendare"],
+    "Attachments folder" : "Mapa s privicima",
     "{filename} could not be parsed" : "Nije moguće parsirati {filename}",
     "No valid files found, aborting import" : "Nisu pronađene važeće datoteke, uvoz je otkazan",
     "Import partially failed. Imported {accepted} out of {total}." : "Djelomično neuspješan uvoz. Uvezeno {accepted} od {total}.",
     "Automatic" : "Automatsko",
-    "Automatic ({detected})" : "Automatsko ({detected})",
+    "Automatic ({timezone})" : "Automatski ({timezone})",
     "New setting was not saved successfully." : "Nova postavka nije uspješno spremljena.",
+    "Timezone" : "Vremenska zona",
     "Navigation" : "Navigacija",
     "Previous period" : "Prethodno razdoblje",
     "Next period" : "Sljedeće razdoblje",
@@ -119,21 +122,16 @@ OC.L10N.register(
     "Actions" : "Radnje",
     "Create event" : "Stvori događaj",
     "Show shortcuts" : "Prikaži prečace",
-    "Shortcut overview" : "Pregled prečaca",
     "or" : "ili",
     "No reminder" : "Nema podsjetnika",
     "CalDAV link copied to clipboard." : "Poveznica kalendara CalDAV kopirana je u međuspremnik.",
     "CalDAV link could not be copied to clipboard." : "Poveznica kalendara CalDAV nije kopirana u međuspremnik.",
-    "Enable birthday calendar" : "Omogući kalendar rođendana",
-    "Show tasks in calendar" : "Prikaži zadatke u kalendaru",
-    "Enable simplified editor" : "Omogući jednostavan uređivač",
-    "Show weekends" : "Prikaži vikende",
-    "Show week numbers" : "Prikaži brojeve tjedana",
-    "Time increments" : "Vremenski prirasti",
-    "Default reminder" : "Zadani podsjetnik",
-    "Copy primary CalDAV address" : "Kopiraj primarnu CalDAV adresu",
+    "General" : "Općenito",
     "Copy iOS/macOS CalDAV address" : "Kopiraj iOS/macOS CalDAV adresu",
-    "Show keyboard shortcuts" : "Prikaži tipkovne prečace",
+    "Appearance" : "Izgled",
+    "Editing" : "Uređivanje",
+    "Default reminder" : "Zadani podsjetnik",
+    "Keyboard shortcuts" : "Tipkovni prečaci",
     "Update" : "Ažuriraj",
     "Location" : "Lokacija",
     "Description" : "Opis",
@@ -153,7 +151,6 @@ OC.L10N.register(
     "Select conversation" : "Odaberi razgovor",
     "on" : "na",
     "at" : "u",
-    "Reminder" : "Podsjetnik",
     "before at" : "prije u",
     "Notification" : "Obavijest",
     "Email" : "E-pošta",
@@ -164,7 +161,6 @@ OC.L10N.register(
     "Edit time" : "Uredi vrijeme",
     "Save time" : "Spremi vrijeme",
     "Remove reminder" : "Ukloni podsjetnik",
-    "+ Add reminder" : "+ Dodaj podsjetnik",
     "Add reminder" : "Dodaj podsjetnik",
     "seconds" : "sekunda",
     "minutes" : "minuta",
@@ -178,13 +174,14 @@ OC.L10N.register(
     "Available" : "Dostupno",
     "Not available" : "Nije dostupno",
     "{organizer} (organizer)" : "{organizer} (organizator)",
+    "Availability of attendees, resources and rooms" : "Raspoloživost sudionika, resursa i soba",
+    "Out of office" : "Izvan ureda",
+    "Attendees:" : "Polaznici:",
+    "Room name" : "Naziv sobe",
     "Free" : "Dostupno",
     "Busy (tentative)" : "Zauzeto (uvjetno)",
     "Busy" : "Zauzeto",
-    "Out of office" : "Izvan ureda",
     "Unknown" : "Nepoznato",
-    "Availability of attendees, resources and rooms" : "Raspoloživost sudionika, resursa i soba",
-    "Room name" : "Naziv sobe",
     "Accept" : "Prihvati",
     "Decline" : "Odbij",
     "Tentative" : "Uvjetno",
@@ -206,7 +203,6 @@ OC.L10N.register(
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Nije moguće mijenjati cjelodnevne postavke za događaje koji su dio skupa ponavljanja.",
     "From" : "Od",
     "To" : "Do",
-    "All day" : "Cijeli dan",
     "Repeat" : "Ponovi",
     "_time_::_times_" : ["put","puta","puta"],
     "never" : "nikad",
@@ -229,7 +225,7 @@ OC.L10N.register(
     "Does not repeat" : "Ne ponavlja se",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Nextcloud ne podržava u potpunosti definiciju ponavljanja za ovaj događaj. Ako uredite mogućnosti ponavljanja, može doći do gubitka određenih ponavljanja.",
     "No rooms or resources yet" : "Još nema soba ili resursa",
-    "Suggestions" : "Prijedlozi",
+    "Resources" : "Resursi",
     "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} sjedalo","{seatingCapacity} sjedala","{seatingCapacity} sjedala"],
     "Add resource" : "Dodaj resurs",
     "Has a projector" : "Ima projektor",
@@ -248,6 +244,10 @@ OC.L10N.register(
     "Update this occurrence" : "Ažuriraj ovo ponavljanje",
     "Public calendar does not exist" : "Javni kalendar ne postoji",
     "Maybe the share was deleted or has expired?" : "Možda je dijeljenje izbrisano ili je isteklo?",
+    "Yes" : "Da",
+    "No" : "Ne",
+    "None" : "Nema",
+    "Create" : "Stvori",
     "from {formattedDate}" : "od {formattedDate}",
     "to {formattedDate}" : "do {formattedDate}",
     "on {formattedDate}" : "{formattedDate}",
@@ -268,14 +268,18 @@ OC.L10N.register(
     "Personal" : "Osobno",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Značajka automatskog otkrivanja vremenske zone utvrdila je vašu vremensku zonu kao UTC.\nVjerojatno zbog sigurnosnih mjera vašeg internetskog preglednika.\nRučno postavite vremensku zonu u postavkama kalendara.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Nije pronađena vaša konfigurirana vremenska zona ({timezoneId}). Postavka vremenske zone vraćena je na UTC.\nPromijenite vremensku zonu u postavkama i prijavite ovu poteškoću.",
+    "Edit event" : "Uredi događaj",
     "Event does not exist" : "Događaj ne postoji",
     "Delete this occurrence" : "Izbriši ovo ponavljanje",
     "Delete this and all future" : "Izbriši ovo i sva buduća ponavljanja",
-    "Details" : "Pojedinosti",
+    "All day" : "Cijeli dan",
     "Invite" : "Poziv",
-    "Resources" : "Resursi",
     "Untitled event" : "Događaj bez naslova",
     "Close" : "Zatvori",
+    "Selected" : "Odabrano",
+    "Title" : "Naslov",
+    "Participants" : "Sudionici",
+    "Submit" : "Šalji",
     "Subscribe to {name}" : "Pretplati se na {name}",
     "Anniversary" : "Godišnjica",
     "Appointment" : "Dogovor",
@@ -342,7 +346,6 @@ OC.L10N.register(
     "When shared show full event" : "Kada se dijeli, prikaži cijeli događaj",
     "When shared show only busy" : "Kada se dijeli, prikaži samo zauzeto",
     "When shared hide this event" : "Kada se dijeli, sakrij događaj",
-    "The visibility of this event in shared calendars." : "Vidljivost ovog događaja u dijeljenim kalendarima.",
     "Add a location" : "Dodaj lokaciju",
     "Status" : "Status",
     "Confirmed" : "Potvrđeno",
@@ -359,6 +362,19 @@ OC.L10N.register(
     "Error while sharing file" : "Pogreška pri dijeljenju datoteke",
     "An error occurred, unable to delete the calendar." : "Došlo je do pogreške, nije moguće izbrisati kalendar.",
     "Imported {filename}" : "Uvezena datoteka {filename}",
-    "User not found" : "Korisnik nije pronađen"
+    "User not found" : "Korisnik nije pronađen",
+    "Hidden" : "Skriveno",
+    "can edit" : "uređivanje moguće",
+    "Automatic ({detected})" : "Automatsko ({detected})",
+    "Shortcut overview" : "Pregled prečaca",
+    "Enable birthday calendar" : "Omogući kalendar rođendana",
+    "Show tasks in calendar" : "Prikaži zadatke u kalendaru",
+    "Enable simplified editor" : "Omogući jednostavan uređivač",
+    "Show weekends" : "Prikaži vikende",
+    "Show week numbers" : "Prikaži brojeve tjedana",
+    "Time increments" : "Vremenski prirasti",
+    "Copy primary CalDAV address" : "Kopiraj primarnu CalDAV adresu",
+    "Show keyboard shortcuts" : "Prikaži tipkovne prečace",
+    "The visibility of this event in shared calendars." : "Vidljivost ovog događaja u dijeljenim kalendarima."
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
