@@ -322,12 +322,10 @@ OC.L10N.register(
     "Decline" : "拒否",
     "Tentative" : "暫定的",
     "No attendees yet" : "出席者はまだいません",
-    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} 招待済み, {confirmedCount} 確定",
     "Successfully appended link to talk room to location." : "トークルームへのリンクをロケーションに追加しました。",
     "Successfully appended link to talk room to description." : "通話ルームへのリンクを説明文に追加しました",
     "Error creating Talk room" : "通話ルームの作成に失敗しました",
     "Attendees" : "参加者",
-    "_%n more guest_::_%n more guests_" : ["ゲスト %n 名追加"],
     "Remove group" : "グループを削除",
     "Remove attendee" : "出席者を削除",
     "Request reply" : "返信をリクエストする",
@@ -345,7 +343,7 @@ OC.L10N.register(
     "Event title" : "イベントタイトル",
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "繰り返しの一部であるイベントの終日設定は変更できません。",
     "From" : "開始",
-    "To" : "〜まで",
+    "To" : "終了",
     "Repeat" : "繰り返し",
     "Repeat event" : "繰り返しイベント",
     "_time_::_times_" : ["回数"],
@@ -566,6 +564,8 @@ OC.L10N.register(
     "Copy primary CalDAV address" : "通常のCalDAVアドレスをコピー",
     "Personal availability settings" : "個人の稼働率設定",
     "Show keyboard shortcuts" : "キーボード ショートカット",
+    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} 招待済み, {confirmedCount} 確定",
+    "_%n more guest_::_%n more guests_" : ["ゲスト %n 名追加"],
     "The visibility of this event in shared calendars." : "共有カレンダーでのこのイベントの表示。"
 },
 "nplurals=1; plural=0;");
