@@ -20,9 +20,7 @@ OC.L10N.register(
     "Deleted" : "Geläscht",
     "Restore" : "Zrécksetzen",
     "Delete permanently" : "Permanent läschen",
-    "Hidden" : "Verstoppt",
     "Share link" : "Link deelen",
-    "can edit" : "kann änneren",
     "Share with users or groups" : "Mat Benotzer oder Gruppen deelen",
     "Save" : "Späicheren",
     "Cancel" : "Ofbriechen",
@@ -56,6 +54,7 @@ OC.L10N.register(
     "after" : "No",
     "Yes" : "Jo",
     "No" : "Nee",
+    "None" : "Keng",
     "Global" : "Global",
     "Subscribe" : "Umellen",
     "Personal" : "Perséinlech",
@@ -68,6 +67,8 @@ OC.L10N.register(
     "Other" : "Aner",
     "When shared show full event" : "Wann et gedeelt gouf, dann de ganzen Evenement uweisen",
     "When shared show only busy" : "Wann et gedeelt gouf, dann nëmmen als beschäftegt uweisen",
-    "When shared hide this event" : "Wann et gedeelt gouf, dann verstopp dëst Evenement"
+    "When shared hide this event" : "Wann et gedeelt gouf, dann verstopp dëst Evenement",
+    "Hidden" : "Verstoppt",
+    "can edit" : "kann änneren"
 },
 "nplurals=2; plural=(n != 1);");
