@@ -114,7 +114,6 @@ OC.L10N.register(
     "Deleting share link …" : "Ištrinama viešinio nuoroda …",
     "{teamDisplayName} (Team)" : "{teamDisplayName} (Komanda)",
     "An error occurred, unable to change the permission of the share." : "Įvykio klaida, nepavyko pakeisti viešinio leidimo.",
-    "can edit" : "gali redaguoti",
     "Unshare with {displayName}" : "Nustoti bendrinti su {displayName}",
     "Share with users or groups" : "Bendrinti su naudotojais ar grupėmis",
     "No users or groups" : "Nėra jokių naudotojų ar grupių",
@@ -132,7 +131,7 @@ OC.L10N.register(
     "Invalid location selected" : "Pasirinkta neteisinga vieta",
     "Attachments folder successfully saved." : "Priedų aplankas sėkmingai įrašytas.",
     "Error on saving attachments folder." : "Klaida įrašant priedų aplanką.",
-    "Default attachments location" : "Numatytoji priedų vieta",
+    "Attachments folder" : "Priedų aplankas",
     "{filename} could not be parsed" : "Nepavyko išnagrinėti {filename}",
     "No valid files found, aborting import" : "Nerasta jokių tinkamų failų, importavimas nutraukiamas",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Sėkmingai importuotas %n įvykis","Sėkmingai importuoti %n įvykiai","Sėkmingai importuota %n įvykių","Sėkmingai importuotas %n įvykis"],
@@ -165,13 +164,8 @@ OC.L10N.register(
     "CalDAV link copied to clipboard." : "CalDAV nuoroda nukopijuota į iškarpinę.",
     "CalDAV link could not be copied to clipboard." : "Nepavyko nukopijuoti CalDAV nuorodą į iškarpinę.",
     "General" : "Bendra",
-    "Personal availability settings" : "Asmeninio pasiekiamumo nustatymai",
-    "Copy primary CalDAV address" : "Kopijuoti pirminį CalDAV adresą",
     "Copy iOS/macOS CalDAV address" : "Kopijuoti iOS/macOS CalDAV adresą",
-    "Enable birthday calendar" : "Įjungti gimtadienių kalendorių",
-    "Show tasks in calendar" : "Rodyti užduotis kalendoriuje",
-    "Show weekends" : "Rodyti savaitgalius",
-    "Show week numbers" : "Rodyti savaičių numerius",
+    "Appearance" : "Išvaizda",
     "Editing" : "Taisymas",
     "Default reminder" : "Numatytasis priminimas",
     "Keyboard shortcuts" : "Spartieji klavišai",
@@ -418,7 +412,6 @@ OC.L10N.register(
     "When shared show full event" : "Bendrinant, rodyti visą įvykio informaciją",
     "When shared show only busy" : "Bendrinant, rodyti tik kaip užimtą laiką",
     "When shared hide this event" : "Bendrinant, slėpti šį įvykį",
-    "The visibility of this event in shared calendars." : "Šio įvykio matomumas bendrinamuose kalendoriuose.",
     "Add a location" : "Pridėti vietą",
     "Status" : "Būsena",
     "Confirmed" : "Patvirtintas",
@@ -442,11 +435,20 @@ OC.L10N.register(
     "Appointment not found" : "Susitikimas nerastas",
     "User not found" : "Naudotojas nerastas",
     "Hidden" : "Paslėpta",
+    "can edit" : "gali redaguoti",
     "Calendar name …" : "Kalendoriaus pavadinimas…",
+    "Default attachments location" : "Numatytoji priedų vieta",
     "Automatic ({detected})" : "Automatinė ({detected})",
     "Shortcut overview" : "Nuorodų apžvalga",
+    "Enable birthday calendar" : "Įjungti gimtadienių kalendorių",
+    "Show tasks in calendar" : "Rodyti užduotis kalendoriuje",
     "Enable simplified editor" : "Įjungti supaprastintą redaktorių",
     "Limit the number of events displayed in the monthly view" : "Riboti mėnesio rodinyje rodomų įvykių skaičių",
-    "Show keyboard shortcuts" : "Rodyti sparčiuosius klavišus"
+    "Show weekends" : "Rodyti savaitgalius",
+    "Show week numbers" : "Rodyti savaičių numerius",
+    "Copy primary CalDAV address" : "Kopijuoti pirminį CalDAV adresą",
+    "Personal availability settings" : "Asmeninio pasiekiamumo nustatymai",
+    "Show keyboard shortcuts" : "Rodyti sparčiuosius klavišus",
+    "The visibility of this event in shared calendars." : "Šio įvykio matomumas bendrinamuose kalendoriuose."
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
