@@ -105,7 +105,7 @@ OC.L10N.register(
     "Restore" : "Atjaunot",
     "Delete permanently" : "Neatgriezeniski izdzēst",
     "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Atkritnes vienumi tiek izdzēsti pēc {numDays} dienām","Atkritnes vienumi tiek izdzēsti pēc {numDays} dienas","Atkritnes vienumi tiek izdzēsti pēc {numDays} dienām"],
-    "Could not update calendar order." : "Nevarēja atjaunināt kalendāra pasūtījumu.",
+    "Could not update calendar order." : "Nevarēja atjaunināt kalendāru secību.",
     "Internal link" : "Iekšējā saite",
     "A private link that can be used with external clients" : "Privāta saite, kas var tikt izmantota ar ārējiem klientiem.",
     "Copy internal link" : "Ievietot iekšējo saiti starpliktuvē",
@@ -282,7 +282,6 @@ OC.L10N.register(
     "Decline" : "Noraidīt",
     "Tentative" : "Mēģinājums",
     "No attendees yet" : "Vēl nav dalībnieku",
-    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} uzaicināti, {confirmedCount} apstiprinājuši",
     "Error creating Talk room" : "Notika kļūda, veidojot tērzēšanas istabu",
     "Attendees" : "Dalībnieki",
     "Remove group" : "Noņemt grupu",
@@ -471,6 +470,7 @@ OC.L10N.register(
     "Copy primary CalDAV address" : "Ievietot starpliktuvē galveno CalDAV adresi",
     "Personal availability settings" : "Personiskās pieejamības iestatījumi",
     "Show keyboard shortcuts" : "Rādīt tastatūras saīsnes taustiņus",
+    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} uzaicināti, {confirmedCount} apstiprinājuši",
     "The visibility of this event in shared calendars." : "Šī notikuma redzamība koplietotos kalendāros."
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
