@@ -42,14 +42,12 @@ OC.L10N.register(
     "Delete permanently" : "бүр мөсөн устгах",
     "Deck" : "Ажлын талбар",
     "Share link" : "Холбоос хуваалцах",
-    "can edit" : "засаж чадна",
     "Share with users or groups" : "Бусад хэрэглэгч, бүлэгт хуваалцах",
     "Save" : "Хадгалах",
     "Filename" : "Файлын нэр",
     "Cancel" : "Цуцлах",
     "Actions" : "Үйл ажиллагаа",
     "General" : "ерөнхий",
-    "Show week numbers" : "7 хоногийн дугаарыг харуулах",
     "Update" : "Шинэчлэх",
     "Location" : "Байршил",
     "Description" : "Тодорхойлолт",
@@ -96,6 +94,8 @@ OC.L10N.register(
     "Status" : "төлөв",
     "Confirmed" : "Баталгаажсан",
     "Categories" : "төрөл",
-    "Hidden" : "Далд"
+    "Hidden" : "Далд",
+    "can edit" : "засаж чадна",
+    "Show week numbers" : "7 хоногийн дугаарыг харуулах"
 },
 "nplurals=2; plural=(n != 1);");
