@@ -114,7 +114,6 @@ OC.L10N.register(
     "Could not update calendar order." : "Kunne ikke oppdatere rekkefølgen på kalendere.",
     "Shared calendars" : "Delte kalendere",
     "Deck" : "Stokk",
-    "Hidden" : "Skjult",
     "Internal link" : "Intern lenke",
     "A private link that can be used with external clients" : "En privat lenke som kan brukes med eksterne klienter",
     "Copy internal link" : "Kopier intern lenke",
@@ -137,12 +136,10 @@ OC.L10N.register(
     "{teamDisplayName} (Team)" : "{teamDisplayName} (Lag)",
     "An error occurred while unsharing the calendar." : "Det oppstod en feil under oppheving av deling av kalenderen.",
     "An error occurred, unable to change the permission of the share." : "En feil oppsto, kan ikke endre rettighetene til delingen.",
-    "can edit" : "kan endre",
     "Unshare with {displayName}" : "Fjern deling med {displayName}",
     "Share with users or groups" : "Del med brukere eller grupper",
     "No users or groups" : "Ingen brukere eller grupper",
     "Failed to save calendar name and color" : "Lagring av kalendernavn og farge feilet",
-    "Calendar name …" : "Kalendernavn…",
     "Never show me as busy (set this calendar to transparent)" : "Vis meg aldri som opptatt (sett denne kalenderen til gjennomsiktig)",
     "Share calendar" : "Del kalender",
     "Unshare from me" : "Fjern deling fra meg",
@@ -160,7 +157,7 @@ OC.L10N.register(
     "Invalid location selected" : "Invalid location selected",
     "Attachments folder successfully saved." : "Vedleggsmappen er lagret.",
     "Error on saving attachments folder." : "Feil ved lagring av vedleggsmappe.",
-    "Default attachments location" : "Standard plassering for vedlegg",
+    "Attachments folder" : "Vedleggsmappe",
     "{filename} could not be parsed" : "{filename} kunne ikke leses",
     "No valid files found, aborting import" : "Ingen gyldig filer funnet, avbryter importering",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Vellykket importert %n hendelse","Vellykket importert %n hendelser"],
@@ -194,13 +191,8 @@ OC.L10N.register(
     "CalDAV link copied to clipboard." : "CalDAV-lenke kopiert til utklippstavlen.",
     "CalDAV link could not be copied to clipboard." : "CalDAV-lenke kunne ikke bli kopiert til utklippstavlen.",
     "General" : "Generell",
-    "Personal availability settings" : "Personlig ledighets-innstillinger",
-    "Copy primary CalDAV address" : "Kopier primær CalDAV-adresse",
     "Copy iOS/macOS CalDAV address" : "Kopier CalDAV-lenke for iOS/macOS",
-    "Enable birthday calendar" : "Aktiver fødselsdagkalender",
-    "Show tasks in calendar" : "Vis oppgaver i kalender",
-    "Show weekends" : "Vis helger",
-    "Show week numbers" : "Vis ukenummer",
+    "Appearance" : "Utseende",
     "Editing" : "Rediger",
     "Default calendar for incoming invitations" : "Standard kalender for innkommende invitasjoner",
     "Default reminder" : "Standardpåminnelse",
@@ -326,12 +318,10 @@ OC.L10N.register(
     "Decline" : "Avslå",
     "Tentative" : "Foreløpig",
     "No attendees yet" : "Ingen deltakere enda",
-    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} invitert, {confirmedCount} bekreftet",
     "Successfully appended link to talk room to location." : "Lenke til talk-rom til plassering er lagt til.",
     "Successfully appended link to talk room to description." : "La til lenke til Talk-rom til beskrivelsen.",
     "Error creating Talk room" : "Feil ved opprettelse av Talk-rom",
     "Attendees" : "Deltakere",
-    "_%n more guest_::_%n more guests_" : ["%n gjest til","%n flere gjester"],
     "Remove group" : "Fjern gruppe",
     "Remove attendee" : "Fjern deltaker",
     "Request reply" : "Be om svar",
@@ -397,6 +387,7 @@ OC.L10N.register(
     "Yes" : "Ja",
     "No" : "Nei",
     "Maybe" : "Kanskje",
+    "None" : "Ingen",
     "Create" : "Opprett",
     "from {formattedDate}" : "fra {formattedDate}",
     "to {formattedDate}" : "til {formattedDate}",
@@ -527,7 +518,6 @@ OC.L10N.register(
     "When shared show full event" : "Vis hele hendelsen om den deles",
     "When shared show only busy" : "Vis kun opptatt om den deles",
     "When shared hide this event" : "Skjul denne hendelsen om den deles",
-    "The visibility of this event in shared calendars." : "Synlighet for denne oppføringen i delte kalendere",
     "Add a location" : "Legg til et sted",
     "Status" : "Status",
     "Confirmed" : "Bekreftet",
@@ -552,11 +542,24 @@ OC.L10N.register(
     "Error while parsing a PROPFIND error" : "Feil under analyse av en PROPFIND-feil",
     "Appointment not found" : "Avtale ikke funnet",
     "User not found" : "Fant ikke brukeren",
+    "Hidden" : "Skjult",
+    "can edit" : "kan endre",
+    "Calendar name …" : "Kalendernavn…",
+    "Default attachments location" : "Standard plassering for vedlegg",
     "Automatic ({detected})" : "Automatisk ({detected})",
     "Shortcut overview" : "Oversikt over snarveier",
+    "Enable birthday calendar" : "Aktiver fødselsdagkalender",
+    "Show tasks in calendar" : "Vis oppgaver i kalender",
     "Enable simplified editor" : "Aktiver forenklet redigering",
     "Limit the number of events displayed in the monthly view" : "Begrens antall hendelser som vises i månedsvisningen",
+    "Show weekends" : "Vis helger",
+    "Show week numbers" : "Vis ukenummer",
     "Time increments" : "Tidsøkninger",
-    "Show keyboard shortcuts" : "Vis tastatursnarveier"
+    "Copy primary CalDAV address" : "Kopier primær CalDAV-adresse",
+    "Personal availability settings" : "Personlig ledighets-innstillinger",
+    "Show keyboard shortcuts" : "Vis tastatursnarveier",
+    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} invitert, {confirmedCount} bekreftet",
+    "_%n more guest_::_%n more guests_" : ["%n gjest til","%n flere gjester"],
+    "The visibility of this event in shared calendars." : "Synlighet for denne oppføringen i delte kalendere"
 },
 "nplurals=2; plural=(n != 1);");
