@@ -116,7 +116,6 @@ OC.L10N.register(
     "Could not update calendar order." : "Kon de volgorde van agenda's niet bijwerken.",
     "Shared calendars" : "Gedeelde agenda's",
     "Deck" : "Deck",
-    "Hidden" : "Verborgen",
     "Internal link" : "Interne link",
     "A private link that can be used with external clients" : "Een privélink die kan worden gebruikt met externe clients",
     "Copy internal link" : "Kopieer interne link",
@@ -139,12 +138,10 @@ OC.L10N.register(
     "{teamDisplayName} (Team)" : "{teamDisplayName}(Team)",
     "An error occurred while unsharing the calendar." : "Er is een fout opgetreden bij het delen van de kalender.",
     "An error occurred, unable to change the permission of the share." : "Er is een fout opgetreden, het is niet mogelijk om de machtiging van de share te wijzigen",
-    "can edit" : "kan wijzigen",
     "Unshare with {displayName}" : "Stop delen met {displayName}",
     "Share with users or groups" : "Deel met gebruikers of groepen",
     "No users or groups" : "Geen gebruikers of groepen",
     "Failed to save calendar name and color" : "Niet gelukt om de naam en kleur van de kalender op te slaan",
-    "Calendar name …" : "Kalendernaam ...",
     "Never show me as busy (set this calendar to transparent)" : "Toon mij nooit als bezet (stel deze agenda in als transparant)",
     "Share calendar" : "Delen kalender",
     "Unshare from me" : "Stop delen met mij",
@@ -162,14 +159,15 @@ OC.L10N.register(
     "Invalid location selected" : "Ongeldige locatie geselecteerd",
     "Attachments folder successfully saved." : "Bijlagenmap succesvol opgeslagen.",
     "Error on saving attachments folder." : "Fout bij het opslaan van de bijlagenmap.",
-    "Default attachments location" : "Standaard bijlagenlocatie",
+    "Attachments folder" : "Bijlagemap",
     "{filename} could not be parsed" : "{filename} kon niet worden geanalyseerd",
     "No valid files found, aborting import" : "Geen geldige bestand gevonden, import afgebroken",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["%nafspraak succesvol geïmporteerd","%n afspraken succesvol geïmporteerd"],
     "Import partially failed. Imported {accepted} out of {total}." : "Import is gedeeltelijk gelukt. Geïmporteerd {accepted} van de {total}.",
     "Automatic" : "Automatisch",
-    "Automatic ({detected})" : "Automatisch ({detected})",
+    "Automatic ({timezone})" : "Automatisch ({timezone})",
     "New setting was not saved successfully." : "De nieuwe instelling is niet goed opgeslagen.",
+    "Timezone" : "Tijdzone",
     "Navigation" : "Navigatie",
     "Previous period" : "Vorige periode",
     "Next period" : "Volgende periode",
@@ -187,7 +185,6 @@ OC.L10N.register(
     "Save edited event" : "Aangepaste afspraak opslaan",
     "Delete edited event" : "Aangepaste afspraak verwijderen",
     "Duplicate event" : "Duplicaat afspraak",
-    "Shortcut overview" : "Snelkoppeling overzicht",
     "or" : "of",
     "Calendar settings" : "Agenda instellingen",
     "At event start" : "Bij start gebeurtenis",
@@ -195,19 +192,13 @@ OC.L10N.register(
     "Failed to save default calendar" : "Kon standaardagenda niet opslaan",
     "CalDAV link copied to clipboard." : "CalDAV link gekopiëerd naar klembord.",
     "CalDAV link could not be copied to clipboard." : "CalDAV link kon niet worden gekopieerd naar klembord.",
-    "Enable birthday calendar" : "Verjaardagskalender inschakelen",
-    "Show tasks in calendar" : "Toon taken in agenda",
-    "Enable simplified editor" : "Eenvoudige editor inschakelen",
-    "Limit the number of events displayed in the monthly view" : "Beperk het aantal evenementen dat wordt weergegeven in de maandweergave",
-    "Show weekends" : "Toon weekenden",
-    "Show week numbers" : "Tonen weeknummers",
-    "Time increments" : "Time-toename",
+    "General" : "Algemeen",
+    "Copy iOS/macOS CalDAV address" : "Kopieer iOS/macOS CalDAV adres",
+    "Appearance" : "Uiterlijk",
+    "Editing" : "Bewerken",
     "Default calendar for incoming invitations" : "Standaardagenda voor inkomende uitnodigingen",
     "Default reminder" : "Standaard herinnering",
-    "Copy primary CalDAV address" : "Kopieer primair CalDAV adres",
-    "Copy iOS/macOS CalDAV address" : "Kopieer iOS/macOS CalDAV adres",
-    "Personal availability settings" : "Persoonlijke beschikbaarheidsinstellingen",
-    "Show keyboard shortcuts" : "Toon sneltoetsen",
+    "Keyboard shortcuts" : "Toetsenbord sneltoetsen",
     "Appointment schedule successfully created" : "Afspraakschema succesvol aangemaakt",
     "Appointment schedule successfully updated" : "Afspraakschema succesvol aangepast",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minuut","{duration} minuten"],
@@ -335,7 +326,6 @@ OC.L10N.register(
     "Decline" : "Afwijzen",
     "Tentative" : "Voorlopig",
     "No attendees yet" : "Nog geen deelnemers",
-    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} uitgenodigd, {confirmedCount} bevestigd",
     "Successfully appended link to talk room to location." : "Succesvol de link naar de Talk ruimte aan de locatie toegevoegd.",
     "Successfully appended link to talk room to description." : "Met succes een link naar de gespreksruimte toegevoegd aan de beschrijving.",
     "Error creating Talk room" : "Fout tijdens aanmaken gespreksruimte",
@@ -403,6 +393,9 @@ OC.L10N.register(
     "Update this occurrence" : "Deze afspraak bijwerken",
     "Public calendar does not exist" : "Publieke agenda bestaat niet",
     "Maybe the share was deleted or has expired?" : "Mogelijk is het gedeelde item verwijderd of verlopen?",
+    "Yes" : "Ja",
+    "No" : "Nee",
+    "None" : "Geen",
     "Create" : "Creëer",
     "from {formattedDate}" : "van {formattedDate}",
     "to {formattedDate}" : "tot {formattedDate}",
@@ -462,7 +455,10 @@ OC.L10N.register(
     "Untitled event" : "Afspraken zonder naam",
     "Close" : "Sluiten",
     "Selected" : "Geselecteerd",
+    "Title" : "Titel",
+    "30 min" : "30 min",
     "Participants" : "Deelnemers",
+    "Submit" : "Indienen",
     "Subscribe to {name}" : "Abonneren op {name}",
     "Export {name}" : "Exporteer {name}",
     "Anniversary" : "Verjaardag",
@@ -531,7 +527,6 @@ OC.L10N.register(
     "When shared show full event" : "Wanneer gedeeld, toon gehele afspraak",
     "When shared show only busy" : "Wanneer gedeeld, toon alleen onbeschikbaarheid",
     "When shared hide this event" : "Wanneer gedeeld, verberg deze afspraak",
-    "The visibility of this event in shared calendars." : "De zichtbaarheid van deze afspraak in gedeelde agenda's.",
     "Add a location" : "Een locatie toevoegen",
     "Status" : "Status",
     "Confirmed" : "Bevestigd",
@@ -553,6 +548,24 @@ OC.L10N.register(
     "Imported {filename}" : "Geïmporteerd {filename}",
     "This is an event reminder." : "Dit is een herinnering aan een evenement.",
     "Appointment not found" : "Afspraak niet gevonden",
-    "User not found" : "Gebruiker niet gevonden"
+    "User not found" : "Gebruiker niet gevonden",
+    "Hidden" : "Verborgen",
+    "can edit" : "kan wijzigen",
+    "Calendar name …" : "Kalendernaam ...",
+    "Default attachments location" : "Standaard bijlagenlocatie",
+    "Automatic ({detected})" : "Automatisch ({detected})",
+    "Shortcut overview" : "Snelkoppeling overzicht",
+    "Enable birthday calendar" : "Verjaardagskalender inschakelen",
+    "Show tasks in calendar" : "Toon taken in agenda",
+    "Enable simplified editor" : "Eenvoudige editor inschakelen",
+    "Limit the number of events displayed in the monthly view" : "Beperk het aantal evenementen dat wordt weergegeven in de maandweergave",
+    "Show weekends" : "Toon weekenden",
+    "Show week numbers" : "Tonen weeknummers",
+    "Time increments" : "Time-toename",
+    "Copy primary CalDAV address" : "Kopieer primair CalDAV adres",
+    "Personal availability settings" : "Persoonlijke beschikbaarheidsinstellingen",
+    "Show keyboard shortcuts" : "Toon sneltoetsen",
+    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} uitgenodigd, {confirmedCount} bevestigd",
+    "The visibility of this event in shared calendars." : "De zichtbaarheid van deze afspraak in gedeelde agenda's."
 },
 "nplurals=2; plural=(n != 1);");
