@@ -93,7 +93,6 @@ OC.L10N.register(
     "Delete share link" : "Cantzella ligòngiu de cumpartzidura",
     "Deleting share link …" : "Cantzellende su ligòngiu de cumpartzidura …",
     "An error occurred, unable to change the permission of the share." : "B'at àpidu un'errore, no at fatu a cambiare su permissu de cumpartzidura.",
-    "can edit" : "podet modificare",
     "Unshare with {displayName}" : "Annulla sa cumpartzidura cun {displayName}",
     "Share with users or groups" : "Cumpartzi cun utentes o grupos",
     "No users or groups" : "Peruna utèntzia o grupu",
@@ -106,6 +105,7 @@ OC.L10N.register(
     "Calendar to import into" : "Calendàriu de importare in",
     "Cancel" : "Annulla",
     "_Import calendar_::_Import calendars_" : ["Importa calendàriu","Importa calendàrios"],
+    "Attachments folder" : "Cartella de alligongiados",
     "{filename} could not be parsed" : "No at fatu a analizare {filename} ",
     "No valid files found, aborting import" : "Perunu archìviu vàlidu agatadu, annullende s'importatzione",
     "Import partially failed. Imported {accepted} out of {total}." : "Parte de s'importatzione est andada male. Importados {accepted} de {total}.",
@@ -127,12 +127,8 @@ OC.L10N.register(
     "No reminder" : "Perunu promemòria",
     "CalDAV link copied to clipboard." : "Ligòngiu CalDAV copiadu in punta de billete.",
     "CalDAV link could not be copied to clipboard." : "No at fatu a copiare su ligòngiu CalDAV in punta de billete.",
-    "Copy primary CalDAV address" : "Còpia s'indiritzu CalDAV printzipale",
     "Copy iOS/macOS CalDAV address" : "Còpia s'indiritzu CalDAV iOS/macOS",
-    "Enable birthday calendar" : "Ativa su calendàriu de cumpleannos",
-    "Show tasks in calendar" : "Mustra atividades in su calendàriu",
-    "Show weekends" : "Mustra fines de chida",
-    "Show week numbers" : "Mustra nùmeru de chidas",
+    "Appearance" : "Aspetu",
     "Default reminder" : "Promemòria predefinidu",
     "Keyboard shortcuts" : "Curtziadòrgios de tecladu",
     "Update" : "Agiorna",
@@ -334,7 +330,6 @@ OC.L10N.register(
     "When shared show full event" : "Cando si cumpartzit mustra totu s'eventu",
     "When shared show only busy" : "Cando si cumpartzit, mustra isceti ocupadu",
     "When shared hide this event" : "Cando si cumpartzit, cua custu eventu",
-    "The visibility of this event in shared calendars." : "Sa visibilidade de custu eventu in is calendàrios cumpartzidos",
     "Add a location" : "Agiunghe una positzione",
     "Status" : "Istadu",
     "Confirmed" : "Cunfirmadu",
@@ -353,10 +348,17 @@ OC.L10N.register(
     "Imported {filename}" : "Importadu {filename}",
     "User not found" : "Utèntzia no agatada",
     "Hidden" : "Cuadu",
+    "can edit" : "podet modificare",
     "Automatic ({detected})" : "Automàticu ({detected})",
     "Shortcut overview" : "Bista generale de is curtziadòrgiu",
+    "Enable birthday calendar" : "Ativa su calendàriu de cumpleannos",
+    "Show tasks in calendar" : "Mustra atividades in su calendàriu",
     "Enable simplified editor" : "Ativa s'editore semplificadu",
+    "Show weekends" : "Mustra fines de chida",
+    "Show week numbers" : "Mustra nùmeru de chidas",
     "Time increments" : "Crèschidas de tempus",
-    "Show keyboard shortcuts" : "Mustra curtziadòrgios de tecladu"
+    "Copy primary CalDAV address" : "Còpia s'indiritzu CalDAV printzipale",
+    "Show keyboard shortcuts" : "Mustra curtziadòrgios de tecladu",
+    "The visibility of this event in shared calendars." : "Sa visibilidade de custu eventu in is calendàrios cumpartzidos"
 },
 "nplurals=2; plural=(n != 1);");
